=== modified file 'ivle/webapp/filesystem/browser/media/browser.js'
--- ivle/webapp/filesystem/browser/media/browser.js	2009-12-01 04:58:10 +0000
+++ ivle/webapp/filesystem/browser/media/browser.js	2009-12-02 00:12:23 +0000
@@ -134,12 +134,14 @@
  *      May be "application/x-www-form-urlencoded" or "multipart/form-data".
  *      Defaults to "application/x-www-form-urlencoded".
  *      "multipart/form-data" is recommended for large uploads.
+ * \param callback, optional.
+ *      A callback function for after the action has been handled.
  */
-function do_action(action, path, args, content_type, ignore_response)
+function do_action(action, path, args, content_type, callback)
 {
     args.action = action;
     /* Callback action, when the server returns */
-    var callback = function(response)
+    var callback_inner = function(response)
         {
             /* Check for action errors reported by the server, and report them
              * to the user */
@@ -149,11 +151,11 @@
                  * allow multi-line error messages. Decode */
                 alert("Error: " + decodeURIComponent(error.toString()) + ".");
             /* Now read the response and set up the page accordingly */
-            if (ignore_response != true)
-                handle_response(path, response, true);
+            if (callback != null)
+                callback(path, response);
         }
     /* Call the server and perform the action. This mutates the server. */
-    ajax_call(callback, service_app, path, args, "POST", content_type);
+    ajax_call(callback_inner, service_app, path, args, "POST", content_type);
 }
 
 /** Calls the server using Ajax, requesting a directory listing. This should
@@ -954,6 +956,12 @@
      * This causes the page to be populated with whatever is at that address,
      * whether it be a directory or a file.
      */
+    var path = get_path();
+    navigate(path);
+}
+
+/** Gets the current path of the window */
+function get_path() {
     var path = parse_url(window.location.href).path;
     /* Strip out root_dir + "/files" from the front of the path */
     var strip = make_path(this_app);
@@ -976,5 +984,5 @@
         path = username;
     }
 
-    navigate(path);
+    return path;
 }

=== modified file 'ivle/webapp/filesystem/browser/media/editor.js'
--- ivle/webapp/filesystem/browser/media/editor.js	2009-08-13 06:23:19 +0000
+++ ivle/webapp/filesystem/browser/media/editor.js	2009-12-02 00:12:23 +0000
@@ -31,7 +31,7 @@
     {
         do_action("putfile", filename,
                   {"path":".", "data":data, "overwrite":"true"},
-                  "multipart/form-data", true);
+                  "multipart/form-data");
         disable_save_if_safe();
     }
 }

=== modified file 'ivle/webapp/filesystem/browser/media/listing.js'
--- ivle/webapp/filesystem/browser/media/listing.js	2009-12-01 04:58:10 +0000
+++ ivle/webapp/filesystem/browser/media/listing.js	2009-12-02 00:12:23 +0000
@@ -41,12 +41,21 @@
 
 /** ACTIONS **/
 
+/** Do a action on the current path and then run the handle_response callback 
+ **/
+function do_act(action, args) {
+    do_action(action, current_path, args, null,
+            function(path, response) {
+                handle_response(path, response, true);
+            });
+}
+
 function action_rename(fromfilename)
 {
     var tofilename = prompt("Rename file \"" + fromfilename + "\" to?",
         fromfilename);
     if (tofilename == null) return;
-    do_action("move", current_path, {"from":fromfilename, "to":tofilename});
+    do_act("move", {"from":fromfilename, "to":tofilename});
     return false;
 }
 
@@ -97,7 +106,7 @@
 
     var confirmed = confirm(conf_msg);
     if (!confirmed) return;
-    do_action("delete", current_path, {"path":files});
+    do_act("delete", {"path":files});
     return false;
 }
 
@@ -105,7 +114,7 @@
 {
     var path = prompt("New directory name?");
     if (path == null) return;
-    do_action("mkdir", current_path, {"path":path});
+    do_act("mkdir", {"path":path});
     return false;
 }
 
@@ -116,7 +125,7 @@
     /* "Upload" a blank file */
     /* Note: "overwrite" defaults to false, so will error if it already
      * exists. */
-    do_action("putfile", current_path, {"path":path, "data":""});
+    do_act("putfile", {"path":path, "data":""});
     return false;
 }
 
@@ -168,7 +177,7 @@
     /* The clip_obj is exactly what we want to pass, plus the current path
      * as destination. */
     clip_obj.dst = ".";
-    do_action("paste", current_path, clip_obj);
+    do_act("paste", clip_obj);
     return false;
 }
 
@@ -186,45 +195,45 @@
 
 function action_add(files)
 {
-    do_action("svnadd", current_path, {"path":files});
+    do_act("svnadd", {"path":files});
     return false;
 }
 
 function action_remove(files)
 {
-    do_action("svnremove", current_path, {"path":files});
+    do_act("svnremove", {"path":files});
     return false;
 }
 
 function action_revert(files)
 {
-    do_action("svnrevert", current_path, {"path":files});
+    do_act("svnrevert", {"path":files});
     return false;
 }
 
 function action_publish(files)
 {
-    do_action("publish", current_path, {"path":files});
+    do_act("publish", {"path":files});
     return false;
 }
 
 function action_unpublish(files)
 {
-    do_action("unpublish", current_path, {"path":files});
+    do_act("unpublish", {"path":files});
     return false;
 }
 
 function action_update(files)
 {
     if (files.length == 0) files = ".";
-    do_action("svnupdate", current_path, {"path": files});
+    do_act("svnupdate", {"path": files});
     return false;
 }
 
 function action_resolved(files)
 {
     if (files.length == 0) files = ".";
-    do_action("svnresolved", current_path, {"path": files});
+    do_act("svnresolved", {"path": files});
     return false;
 }
 
@@ -233,13 +242,13 @@
     /* Get a commit log from the user */
     var logmsg = prompt("Enter commit log:");
     if (logmsg == null) return;
-    do_action("svncommit", current_path, {"path":files, "logmsg": logmsg});
+    do_act("svncommit", {"path":files, "logmsg": logmsg});
     return false;
 }
 
 function action_svncleanup(path)
 {
-    do_action("svncleanup", current_path, {"path": path});
+    do_act("svncleanup", {"path": path});
     alert("Subversion Cleanup Complete");
 }
 

=== modified file 'ivle/webapp/filesystem/browser/media/specialhome.js'
--- ivle/webapp/filesystem/browser/media/specialhome.js	2009-03-25 11:03:05 +0000
+++ ivle/webapp/filesystem/browser/media/specialhome.js	2009-12-02 00:12:23 +0000
@@ -198,8 +198,7 @@
                 if (create_if_needed(repopath))
                 {
                     // Try a checkout
-                    do_action("svncheckout", current_path, {"path":
-                        [repopath, localpath]});
+                    do_act("svncheckout", {"path": [repopath, localpath]});
                 }
                 else
                 {

